#! /usr/bin/env python
# coding: utf-8

import os
import matplotlib.pyplot as plt
import emiss.inversion


RESULTS_PATH = '/project/kug/smartcarb/results/Berlin/flux_inversion/analytical/'

CONSTANT_FNAMES = [
    os.path.join(RESULTS_PATH, 'CO2_Berlin_constant_model-bg_05ppm.dat'),
    os.path.join(RESULTS_PATH, 'CO2_Berlin_constant_model-bg_07ppm.dat'),
    os.path.join(RESULTS_PATH, 'CO2_Berlin_constant_model-bg_10ppm.dat'),
]

VARIABLE_FNAMES = [
    os.path.join(RESULTS_PATH, 'CO2_Berlin_vari_model-bg_05ppm.dat'),
    os.path.join(RESULTS_PATH, 'CO2_Berlin_vari_model-bg_07ppm.dat'),
    os.path.join(RESULTS_PATH, 'CO2_Berlin_vari_model-bg_10ppm.dat'),
]

MC_PATH = '/project/kug/smartcarb/results/Berlin/flux_inversion/mass-balance/results_mc/'
MASS_BALANCE_FNAMES_CO2 = [
    os.path.join(MC_PATH, 'CO2-0.5ppm_Berlin.dat'),
    os.path.join(MC_PATH, 'CO2-0.7ppm_Berlin.dat'),
    os.path.join(MC_PATH, 'CO2-1.0ppm_Berlin.dat'),
]
MASS_BALANCE_FNAMES_NO2 = [
    os.path.join(MC_PATH, 'NO2-0.5ppm_Berlin.dat'),
    os.path.join(MC_PATH, 'NO2-0.7ppm_Berlin.dat'),
    os.path.join(MC_PATH, 'NO2-1.0ppm_Berlin.dat'),
]


def get_shared_indices():
    """
    Get indices for emission estimates with useful estimations in all scenarios
    (noise levels as well as time-varying and constant emissions)
    """
    pass


def main(emissions):
    use_constant = (emissions == 'time-constant')

    if use_constant:
        input_fnames = CONSTANT_FNAMES
    else:
        input_fnames = VARIABLE_FNAMES

    # time series for each scenarios
    for noise, filename in zip([0.5, 0.7, 1.0], input_fnames):
        emiss.inversion.plot_ts(filename, nsat=6, use_constant=use_constant,
                                origin='Berlin', nmax=None, is_mce=False)

        img_fname = os.path.join(
            'figures',
            'CO2_%.1fppm_Berlin_%s_emissions.pdf' % (noise, emissions)
        )

        plt.savefig(img_fname)
        plt.close()


    # box plots
    # (a) with all useful estimates (unc. < 50% of annual emissions)
    # (b) with same plumes in each scenario
    print("Same samples (%s):" % emissions)
    res = emiss.inversion.boxplot(input_fnames, nsat=6, sample='same',
                                  use_constant=use_constant)
    img_fname = os.path.join(
        'figures',
        'CO2_boxplots_Berlin_%s_emissions.pdf' % emissions
    )
    plt.savefig(img_fname)
    plt.close()

    print("All samples (%s):" % emissions)
    res = emiss.inversion.boxplot(input_fnames, nsat=6, sample='all',
                                  use_constant=use_constant)
    plt.close()

    # table: 
    # - MB and SD for same plumes in each scenario
    # - RMSD for same and for all useful estimates



if __name__ == '__main__':
    main('time-constant')
    main('time-varying')
